@@ -83,20 +83,20 @@ class Configure:
 		return self._pgen
 
 	@property
-	def ipv6(self):
-		"""ipv6 commands group. 0 Sub-classes, 1 commands."""
-		if not hasattr(self, '_ipv6'):
-			from .Configure_.Ipv6 import Ipv6
-			self._ipv6 = Ipv6(self._core, self._base)
-		return self._ipv6
+	def ipvSix(self):
+		"""ipvSix commands group. 0 Sub-classes, 1 commands."""
+		if not hasattr(self, '_ipvSix'):
+			from .Configure_.IpvSix import IpvSix
+			self._ipvSix = IpvSix(self._core, self._base)
+		return self._ipvSix
 
 	@property
-	def ipv4(self):
-		"""ipv4 commands group. 1 Sub-classes, 1 commands."""
-		if not hasattr(self, '_ipv4'):
-			from .Configure_.Ipv4 import Ipv4
-			self._ipv4 = Ipv4(self._core, self._base)
-		return self._ipv4
+	def ipvFour(self):
+		"""ipvFour commands group. 1 Sub-classes, 1 commands."""
+		if not hasattr(self, '_ipvFour'):
+			from .Configure_.IpvFour import IpvFour
+			self._ipvFour = IpvFour(self._core, self._base)
+		return self._ipvFour
 
 	@property
 	def hetBased(self):
