@@ -123,19 +123,19 @@ class Hetf:
 		Snippet: value: enums.Giltf = driver.configure.connection.hetf.get_gilt() \n
 		Specifies the guard interval and LTF type of the HE TB PPDU. For method RsCmwWlanSig.Configure.Connection.Hetf.mltf MASK,
 		the value '1x HE-LTF + 1.6 µs GI' is not supported. \n
-			:return: gi_ltf: L116 | L216 | L432 LTF type and corresponding GI: L116: 1x HE-LTF + 1.6 µs GI L216: 2x HE-LTF + 1.6 µs GI L432: 4x HE-LTF + 3.2 µs GI
+			:return: giltf: L116 | L216 | L432 LTF type and corresponding GI: L116: 1x HE-LTF + 1.6 µs GI L216: 2x HE-LTF + 1.6 µs GI L432: 4x HE-LTF + 3.2 µs GI
 		"""
 		response = self._core.io.query_str('CONFigure:WLAN:SIGNaling<Instance>:CONNection:HETF:GILT?')
 		return Conversions.str_to_scalar_enum(response, enums.Giltf)
 
-	def set_gilt(self, gi_ltf: enums.Giltf) -> None:
+	def set_gilt(self, giltf: enums.Giltf) -> None:
 		"""SCPI: CONFigure:WLAN:SIGNaling<instance>:CONNection:HETF:GILT \n
-		Snippet: driver.configure.connection.hetf.set_gilt(gi_ltf = enums.Giltf.L116) \n
+		Snippet: driver.configure.connection.hetf.set_gilt(giltf = enums.Giltf.L116) \n
 		Specifies the guard interval and LTF type of the HE TB PPDU. For method RsCmwWlanSig.Configure.Connection.Hetf.mltf MASK,
 		the value '1x HE-LTF + 1.6 µs GI' is not supported. \n
-			:param gi_ltf: L116 | L216 | L432 LTF type and corresponding GI: L116: 1x HE-LTF + 1.6 µs GI L216: 2x HE-LTF + 1.6 µs GI L432: 4x HE-LTF + 3.2 µs GI
+			:param giltf: L116 | L216 | L432 LTF type and corresponding GI: L116: 1x HE-LTF + 1.6 µs GI L216: 2x HE-LTF + 1.6 µs GI L432: 4x HE-LTF + 3.2 µs GI
 		"""
-		param = Conversions.enum_scalar_to_str(gi_ltf, enums.Giltf)
+		param = Conversions.enum_scalar_to_str(giltf, enums.Giltf)
 		self._core.io.write(f'CONFigure:WLAN:SIGNaling<Instance>:CONNection:HETF:GILT {param}')
 
 	# noinspection PyTypeChecker
