@@ -118,18 +118,18 @@ class NdpSounding:
 		self._core.io.write(f'CONFigure:WLAN:SIGNaling<Instance>:CONNection:NDPSounding:SPSTreams {param}')
 
 	# noinspection PyTypeChecker
-	def get_ltfgi(self) -> enums.LtfGi:
+	def get_ltf_gi(self) -> enums.LtfGi:
 		"""SCPI: CONFigure:WLAN:SIGNaling<instance>:CONNection:NDPSounding:LTFGi \n
-		Snippet: value: enums.LtfGi = driver.configure.connection.ndpSounding.get_ltfgi() \n
+		Snippet: value: enums.LtfGi = driver.configure.connection.ndpSounding.get_ltf_gi() \n
 		Selects the GI / LTF combination for NDP sounding procedure. \n
 			:return: ltf_gi: L208 | L216 | L432 'L208': 2x HE-LTF + 0.8 µs GI 'L216': 2x HE-LTF + 1.6 µs GI 'L432': 4x HE-LTF + 3.2 µs GI (optional)
 		"""
 		response = self._core.io.query_str('CONFigure:WLAN:SIGNaling<Instance>:CONNection:NDPSounding:LTFGi?')
 		return Conversions.str_to_scalar_enum(response, enums.LtfGi)
 
-	def set_ltfgi(self, ltf_gi: enums.LtfGi) -> None:
+	def set_ltf_gi(self, ltf_gi: enums.LtfGi) -> None:
 		"""SCPI: CONFigure:WLAN:SIGNaling<instance>:CONNection:NDPSounding:LTFGi \n
-		Snippet: driver.configure.connection.ndpSounding.set_ltfgi(ltf_gi = enums.LtfGi.L208) \n
+		Snippet: driver.configure.connection.ndpSounding.set_ltf_gi(ltf_gi = enums.LtfGi.L208) \n
 		Selects the GI / LTF combination for NDP sounding procedure. \n
 			:param ltf_gi: L208 | L216 | L432 'L208': 2x HE-LTF + 0.8 µs GI 'L216': 2x HE-LTF + 1.6 µs GI 'L432': 4x HE-LTF + 3.2 µs GI (optional)
 		"""
