@@ -35,9 +35,9 @@ class Per:
 		"""Structure for reading output parameters. Fields: \n
 			- Format_Py: enums.DataFormatExt: NHT | HTM | VHT | HES | HEM Selects the frame format NHT: non-high throughput format (non-HT) HTM: HT mixed format (HT MF) VHT: very high throughput format HES: high efficiency single-user format (HE SU) HEM: high efficiency multi-user format (HE MU)
 			- Bandwidth: enums.ChannelBandwidthDut: BW20 | BW40 | BW80 | BW160 Channel bandwidth The value must not exceed the operating channel bandwidth, see [CMDLINK: CONFigure:WLAN:SIGNi:RFSettings:OCWidth CMDLINK].
-			- Code_Rate: enums.CodeRate: BR12 | QR12 | QR34 | Q1M12 | Q1M34 | Q6M23 | Q6M34 | BR34 | MCS | MCS1 | MCS2 | MCS3 | MCS4 | MCS5 | MCS6 | MCS7 | D1MBit | D2MBits | C55Mbits | C11Mbits | MCS8 | MCS9 | MCS10 | MCS11 | MCS12 | MCS13 | MCS14 | MCS15 See rate list in [CMDLINK: CONFigure:WLAN:SIGNi:CONNection:MFDef CMDLINK]
+			- Coderate: enums.Coderate: BR12 | QR12 | QR34 | Q1M12 | Q1M34 | Q6M23 | Q6M34 | BR34 | MCS | MCS1 | MCS2 | MCS3 | MCS4 | MCS5 | MCS6 | MCS7 | D1MBit | D2MBits | C55Mbits | C11Mbits | MCS8 | MCS9 | MCS10 | MCS11 | MCS12 | MCS13 | MCS14 | MCS15 See rate list in [CMDLINK: CONFigure:WLAN:SIGNi:CONNection:MFDef CMDLINK]
 			- Guard_Interval: enums.GuardInterval: LONG | SHORt | GI08 | GI16 | GI32 SHORt, LONG: short or long guard interval (up to 802.11ac) GI08, GI16, GI32: 0.8 μs, 1.6 μs, and 3.2 μs guard interval durations (for 802.11ax)
-			- Lt_Ftype: enums.LtfType: X1 | X2 | X4 1x HE-LTF, 2x HE-LTF, 4x HE-LTF for 802.11ax
+			- Ltf_Type: enums.LtfType: X1 | X2 | X4 1x HE-LTF, 2x HE-LTF, 4x HE-LTF for 802.11ax
 			- Pe_Duration: enums.PeDuration: PE0 | PE4 | PE8 | PE12 | PE16 | AUTO PEx: additional receive processing time of x μs signaled in packet extension (PE) field (only for 802.11ax) AUTO: automatic setting based on the reported DUTs capabilities
 			- Ctype: enums.CodingType: LDPC | BCC Coding type (for 802.11ax - VHT, HE_SU, HE_MU frames only) : low density parity check or binary convolution code
 			- Streams: enums.Streams: STR1 | STR2 Number of streams
@@ -45,9 +45,9 @@ class Per:
 		__meta_args_list = [
 			ArgStruct.scalar_enum('Format_Py', enums.DataFormatExt),
 			ArgStruct.scalar_enum('Bandwidth', enums.ChannelBandwidthDut),
-			ArgStruct.scalar_enum('Code_Rate', enums.CodeRate),
+			ArgStruct.scalar_enum('Coderate', enums.Coderate),
 			ArgStruct.scalar_enum('Guard_Interval', enums.GuardInterval),
-			ArgStruct.scalar_enum('Lt_Ftype', enums.LtfType),
+			ArgStruct.scalar_enum('Ltf_Type', enums.LtfType),
 			ArgStruct.scalar_enum('Pe_Duration', enums.PeDuration),
 			ArgStruct.scalar_enum('Ctype', enums.CodingType),
 			ArgStruct.scalar_enum('Streams', enums.Streams),
@@ -57,9 +57,9 @@ class Per:
 			StructBase.__init__(self, self)
 			self.Format_Py: enums.DataFormatExt = None
 			self.Bandwidth: enums.ChannelBandwidthDut = None
-			self.Code_Rate: enums.CodeRate = None
+			self.Coderate: enums.Coderate = None
 			self.Guard_Interval: enums.GuardInterval = None
-			self.Lt_Ftype: enums.LtfType = None
+			self.Ltf_Type: enums.LtfType = None
 			self.Pe_Duration: enums.PeDuration = None
 			self.Ctype: enums.CodingType = None
 			self.Streams: enums.Streams = None
