@@ -47,18 +47,18 @@ class RfSettings:
 		param = Conversions.enum_scalar_to_str(value, enums.ChannelBandwidthDut)
 		self._core.io.write(f'CONFigure:WLAN:SIGNaling<Instance>:RFSettings:OCWidth {param}')
 
-	def get_freq_offset(self) -> int:
+	def get_foffset(self) -> int:
 		"""SCPI: CONFigure:WLAN:SIGNaling<instance>:RFSettings:FOFFset \n
-		Snippet: value: int = driver.configure.rfSettings.get_freq_offset() \n
+		Snippet: value: int = driver.configure.rfSettings.get_foffset() \n
 		Specifies a positive or negative frequency offset to be added to the configured center frequency. \n
 			:return: offset: integer Range: -100 kHz to 100 kHz, Unit: Hz
 		"""
 		response = self._core.io.query_str('CONFigure:WLAN:SIGNaling<Instance>:RFSettings:FOFFset?')
 		return Conversions.str_to_int(response)
 
-	def set_freq_offset(self, offset: int) -> None:
+	def set_foffset(self, offset: int) -> None:
 		"""SCPI: CONFigure:WLAN:SIGNaling<instance>:RFSettings:FOFFset \n
-		Snippet: driver.configure.rfSettings.set_freq_offset(offset = 1) \n
+		Snippet: driver.configure.rfSettings.set_foffset(offset = 1) \n
 		Specifies a positive or negative frequency offset to be added to the configured center frequency. \n
 			:param offset: integer Range: -100 kHz to 100 kHz, Unit: Hz
 		"""
