@@ -17,7 +17,7 @@ class Ipv:
 		Snippet: value: str = driver.sense.uesInfo.cmwAddress.ipv.get(ipVersion = repcap.IpVersion.Default) \n
 		Queries the IP address of the R&S CMW. \n
 			:param ipVersion: optional repeated capability selector. Default value: V4 (settable in the interface 'CmwAddress')
-			:return: ip_address: string The assigned IPv4 address or first IPv6 address prefix."""
+			:return: ip_address: string The assigned IPv4 or IPv6 addresses."""
 		ipVersion_cmd_val = self._base.get_repcap_cmd_value(ipVersion, repcap.IpVersion)
 		response = self._core.io.query_str(f'SENSe:WLAN:SIGNaling<Instance>:UESinfo:CMWaddress:IPV{ipVersion_cmd_val}?')
 		return trim_str_response(response)
