@@ -11,7 +11,7 @@ from .Internal.RepeatedCapability import RepeatedCapability
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
 class RsCmwWlanSig:
 	"""244 total commands, 13 Sub-groups, 0 group commands"""
-	driver_options = "SupportedInstrModels = CMW500/CMW100/CMW270/CMW280/CMP, SupportedIdnPatterns = CMW, SimulationIdnString = 'Rohde&Schwarz,CMW500,100001,3.8.20.0039'"
+	_driver_options = "SupportedInstrModels = CMW500/CMW100/CMW270/CMW280/CMP, SupportedIdnPatterns = CMW, SimulationIdnString = 'Rohde&Schwarz,CMW500,100001,3.8.20.0040'"
 
 	def __init__(self, resource_name: str, id_query: bool = True, reset: bool = False, options: str = None, direct_session: object = None):
 		"""Initializes new RsCmwWlanSig session. \n
@@ -36,8 +36,8 @@ class RsCmwWlanSig:
 		:param reset: Resets the instrument (sends *RST command) and clears its status sybsystem
 		:param options: string tokens alternating the driver settings.
 		:param direct_session: Another driver object or pyVisa object to reuse the session instead of opening a new session."""
-		self._core = Core(resource_name, id_query, reset, RsCmwWlanSig.driver_options, options, direct_session)
-		self._core.driver_version = '3.8.20.0039'
+		self._core = Core(resource_name, id_query, reset, RsCmwWlanSig._driver_options, options, direct_session)
+		self._core.driver_version = '3.8.20.0040'
 		self._options = options
 		self._add_all_global_repcaps()
 		self._custom_properties_init()
@@ -46,7 +46,7 @@ class RsCmwWlanSig:
 
 	@classmethod
 	def from_existing_session(cls, session: object, options: str = None) -> 'RsCmwWlanSig':
-		"""Creates a new RsCmwBluetoothSig object with the entered 'session' reused. \n
+		"""Creates a new RsCmwWlanSig object with the entered 'session' reused. \n
 		:param session: can be an another driver or a direct pyvisa session.
 		:param options: string tokens alternating the driver settings."""
 		# noinspection PyTypeChecker
@@ -63,7 +63,7 @@ class RsCmwWlanSig:
 		"""Asserts that the driver version fulfills the minimum required version you have entered.
 		This way you make sure your installed driver is of the entered version or newer."""
 		min_version_list = min_version.split('.')
-		curr_version_list = '3.8.20.0039'.split('.')
+		curr_version_list = '3.8.20.0040'.split('.')
 		count_min = len(min_version_list)
 		count_curr = len(curr_version_list)
 		count = count_min if count_min < count_curr else count_curr
@@ -73,7 +73,7 @@ class RsCmwWlanSig:
 			if curr > minimum:
 				break
 			if curr < minimum:
-				raise RsInstrException(f"Assertion for minimum RsCmwWlanSig version failed. Current version: '3.8.20.0039', minimum required version: '{min_version}'")
+				raise RsInstrException(f"Assertion for minimum RsCmwWlanSig version failed. Current version: '3.8.20.0040', minimum required version: '{min_version}'")
 				
 	@staticmethod
 	def list_resources(expression: str = '?*::INSTR', visa_select: str = None) -> List[str]:
@@ -230,6 +230,7 @@ class RsCmwWlanSig:
 		"""Creates a deep copy of the RsCmwWlanSig object. Also copies:
 			- All the existing Global repeated capability values
 			- All the default group repeated capabilities setting \n
+		Does not check the *IDN? response, and does not perform Reset.
 		After cloning, you can set all the repeated capabilities settings independentely from the original group.
 		Calling close() on the new object does not close the original VISA session"""
 		cloned = RsCmwWlanSig.from_existing_session(self.get_session_handle(), self._options)
