@@ -138,7 +138,7 @@ class ChannelBandwidthDut(Enum):
 
 
 # noinspection SpellCheckingInspection
-class CodeRate(Enum):
+class Coderate(Enum):
 	"""28 Members, BR12 ... QR34"""
 	BR12 = 0
 	BR34 = 1
@@ -355,7 +355,7 @@ class IpAddrIndex(Enum):
 
 
 # noinspection SpellCheckingInspection
-class Ipv6AddField(Enum):
+class IpV6AddField(Enum):
 	"""3 Members, AATNknown ... ATNavailable"""
 	AATNknown = 0
 	ATAVailable = 1
@@ -363,7 +363,7 @@ class Ipv6AddField(Enum):
 
 
 # noinspection SpellCheckingInspection
-class Ipv6AddFieldExt(Enum):
+class IpV6AddFieldExt(Enum):
 	"""8 Members, AATNknown ... SNPiaavailab"""
 	AATNknown = 0
 	ATNavailable = 1
